@@ -1,4 +1,5 @@
 from .base import (
+    BasePath,
     Blob,
     BlobStat,
     Bucket,
@@ -21,4 +22,4 @@ from .clients import (
     use_fs_cache,
 )
 from .file import BlobFS, BucketClientFS, BucketEntryFS, BucketFS
-from .gcs import BlobGCS, BucketClientGCS, BucketEntryGCS, BucketGCS
+from .gcs import BlobGCS, BucketClientGCS, BucketEntryGCS, BucketGCS, has_gcs
