@@ -3,6 +3,7 @@ from dataclasses import dataclass
 from io import DEFAULT_BUFFER_SIZE
 from pathlib import _Accessor  # type:ignore
 from pathlib import _PosixFlavour  # type:ignore
+from pathlib import _WindowsFlavour  # type:ignore
 from pathlib import Path, PurePath
 from typing import (
     IO,
@@ -25,11 +26,14 @@ import smart_open
 SUBCLASS_ERROR = "must be implemented in a subclass"
 
 StreamableType = IO[Any]
-FluidPath = Union["Pathy", Path]
+FluidPath = Union["Pathy", "BasePath"]
 BucketClientType = TypeVar("BucketClientType", bound="BucketClient")
 BucketType = TypeVar("BucketType")
 BucketBlobType = TypeVar("BucketBlobType")
 
+_windows_flavour = _WindowsFlavour()
+_posix_flavour = _PosixFlavour()
+
 
 @dataclass
 class ClientError(BaseException):
@@ -47,6 +51,7 @@ class ClientError(BaseException):
 class BlobStat:
     """Stat for a bucket item"""
 
+    name: str
     size: Optional[int]
     last_modified: Optional[int]
 
@@ -86,7 +91,7 @@ class BucketEntry(Generic[BucketType, BucketBlobType]):
         self.name = name
         self.raw = raw
         self._is_dir = is_dir
-        self._stat = BlobStat(size=size, last_modified=last_modified)
+        self._stat = BlobStat(name=name, size=size, last_modified=last_modified)
 
     def __repr__(self) -> str:
         return "{}(name={}, is_dir={}, stat={})".format(
@@ -303,6 +308,27 @@ class PurePathy(PurePath):
 _SUPPORTED_OPEN_MODES = {"r", "rb", "tr", "rt", "w", "wb", "bw", "wt", "tw"}
 
 
+class _PathyExtensions:
+    def ls(self) -> Generator["BlobStat", None, None]:
+        blobs: "PathyScanDir" = self._accessor.scandir(self)  # type:ignore
+        for blob in blobs:
+            if hasattr(blob, "_stat"):
+                yield blob._stat
+            elif isinstance(blob, os.DirEntry):
+                os_blob = cast(os.DirEntry, blob)
+                stat = os_blob.stat()
+                file_size = stat.st_size
+                updated = int(round(stat.st_mtime))
+                yield BlobStat(name=os_blob.name, size=file_size, last_modified=updated)
+
+
+class BasePath(_PathyExtensions, Path):
+    # NOTE: pathlib normally takes care of this, but the logic checks
+    #       for specifically "Path" type class in __new__ so we need to
+    #       set the flavour manually based on the OS.
+    _flavour = _windows_flavour if os.name == "nt" else _posix_flavour  # type:ignore
+
+
 class BucketsAccessor(_Accessor):
     """Access data from blob buckets"""
 
@@ -337,7 +363,7 @@ class BucketsAccessor(_Accessor):
         blob: Optional[Blob] = bucket.get_blob(str(path.key))
         if blob is None:
             raise FileNotFoundError(path)
-        return BlobStat(size=blob.size, last_modified=blob.updated)
+        return BlobStat(name=str(blob), size=blob.size, last_modified=blob.updated)
 
     def is_dir(self, path: "Pathy") -> bool:
         if str(path) == path.root:
@@ -453,7 +479,7 @@ class BucketsAccessor(_Accessor):
                 raise OSError(f"Blob already exists: {path}")
 
 
-class Pathy(Path, PurePathy):
+class Pathy(Path, PurePathy, _PathyExtensions):
     """Subclass of `pathlib.Path` that works with bucket APIs."""
 
     __slots__ = ()
@@ -497,7 +523,7 @@ class Pathy(Path, PurePathy):
         """
         from_path: FluidPath = Pathy(path_candidate)
         if from_path.root in ["/", ""]:
-            from_path = Path(path_candidate)
+            from_path = BasePath(path_candidate)
         return from_path
 
     @classmethod
@@ -571,6 +597,16 @@ class Pathy(Path, PurePathy):
                     Pathy.to_local(blob, recurse=False)
         return cache_blob
 
+    def ls(self: "Pathy") -> Generator["BlobStat", None, None]:
+        """List blob names with stat information under the given path.
+
+        This is considerably faster than using iterdir if you also need
+        the stat information for the enumerated blobs.
+
+        Yields BlobStat objects for each found blob.
+        """
+        yield from super(Pathy, self).ls()
+
     def stat(self: "Pathy") -> BlobStat:  # type: ignore[override]
         """Returns information about this bucket path."""
         self._absolute_path_validation()
